@@ -45,7 +45,7 @@ switch (nvl($mode)) {
 		$errors = new Object;
 		$errormsg = "";
 		validate_category_name($HTTP_POST_VARS["name"], &$errors, &$errormsg);
-		validate_on_special($HTTP_POST_VARS["on_special"], &$errors, &$errormsg);
+		validate_special_level($HTTP_POST_VARS["special_level"], &$errors, &$errormsg);
 		validate_category_description($HTTP_POST_VARS["description"], &$errors, &$errormsg);
 		if (empty($errormsg)) {
 			insert_subcategory($id, $HTTP_POST_VARS);
@@ -56,7 +56,7 @@ switch (nvl($mode)) {
 			$frm["categories"] = $HTTP_POST_VARS["categories"];
 			$frm["newmode"] = "insert";
 			$frm["name"] = $HTTP_POST_VARS["name"];
-			$frm["on_special"] = $HTTP_POST_VARS["on_special"];
+			$frm["special_level"] = $HTTP_POST_VARS["special_level"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["submit_caption"] = $Add_Subcategory;
 			/* build the categories listbox options, preselect the selected item */
@@ -70,7 +70,7 @@ switch (nvl($mode)) {
 		$errors = new Object;
 		$errormsg = "";
 		validate_category_name($HTTP_POST_VARS["name"], &$errors, &$errormsg);
-		validate_on_special($HTTP_POST_VARS["on_special"], &$errors, &$errormsg);
+		validate_special_level($HTTP_POST_VARS["special_level"], &$errors, &$errormsg);
 		validate_category_description($HTTP_POST_VARS["description"], &$errors, &$errormsg);
 		if (empty($errormsg)) {
 			update_category($id, $HTTP_POST_VARS);
@@ -81,7 +81,7 @@ switch (nvl($mode)) {
 			$frm["categories"] = $HTTP_POST_VARS["categories"];
 			$frm["newmode"] = "update";
 			$frm["name"] = $HTTP_POST_VARS["name"];
-			$frm["on_special"] = $HTTP_POST_VARS["on_special"];
+			$frm["special_level"] = $HTTP_POST_VARS["special_level"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["submit_caption"] = $Save_Changes;
 			/* build the categories listbox options, preselect the selected item */
@@ -126,7 +126,7 @@ function print_add_category_form($id) {
 	$frm["parent"] = array($id);
 	$frm["newmode"] = "insert";
 	$frm["name"] = "";
-	$frm["on_special"] = "";
+	$frm["special_level"] = "";
 	$frm["description"] = "";
 	$frm["submit_caption"] = $Add_Subcategory;
 
@@ -145,7 +145,7 @@ function print_edit_category_form($id) {
 
 	/* load up the information for the category */
 	$qid = db_query("
-	SELECT name, on_special, description, parent_id
+	SELECT name, special_level, description, parent_id
 	FROM categories
 	WHERE id = '$id'
 	");
@@ -233,8 +233,8 @@ function insert_subcategory($id, $frm) {
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
 	$qid = db_query("
-	INSERT INTO categories (parent_id, name, on_special, description)
-	VALUES ('$frm[parent]', '$frm[name]', '$frm[on_special]', '$frm[description]')
+	INSERT INTO categories (parent_id, name, special_level, description)
+	VALUES ('$frm[parent]', '$frm[name]', '$frm[special_level]', '$frm[description]')
 	");
 
 	include("templates/category_added.ihtml");
@@ -255,7 +255,7 @@ function update_category($id, $frm) {
 	UPDATE categories SET
 		 parent_id = '$frm[parent]'
 		,name = '$frm[name]'
-		,on_special = '$frm[on_special]'
+		,special_level = '$frm[special_level]'
 		,description = '$frm[description]'
 	WHERE id = '$id'
 	");
@@ -272,7 +272,7 @@ function print_category_list() {
 
 	if (!isset($page_number) || $dbchanged) {
 		$qid = db_query("
-		SELECT cat.id, cat.name, cat.on_special, cat.description, parent.name AS parent
+		SELECT cat.id, cat.name, cat.special_level, cat.description, parent.name AS parent
 		FROM categories cat, categories parent
 		WHERE parent.id = cat.parent_id AND cat.id > 1 ORDER BY cat.name
 		");
@@ -365,7 +365,7 @@ function import_category($userfile) {
 			if (db_num_rows($qid) == 0) {
 				/* ... if it doesn't exist let's create it ... */
 				$qid = db_query("
-				INSERT INTO categories (parent_id, name, on_special, description)
+				INSERT INTO categories (parent_id, name, special_level, description)
 				VALUES ('$pid', '$fldarr[1]', '$fldarr[2]', '$fldarr[3]')
 				");
 			} else {
@@ -377,7 +377,7 @@ function import_category($userfile) {
 				UPDATE categories SET
 	 				parent_id = '$pid'
 					,name = '$fldarr[1]'
-					,on_special = '$fldarr[2]'
+					,special_level = '$fldarr[2]'
 					,description = '$fldarr[3]'
 				WHERE id = '$sid'
 				");
