@@ -50,7 +50,7 @@ switch (nvl($mode)) {
 		validate_discount($HTTP_POST_VARS["discount"], $HTTP_POST_VARS["discqty"], &$errors, &$errormsg);
 		if($SESSION["weight_used"])
 			validate_weight($HTTP_POST_VARS["weight"], &$errors, &$errormsg);
-		validate_on_special($HTTP_POST_VARS["on_special"], &$errors, &$errormsg);
+		validate_special_level($HTTP_POST_VARS["special_level"], &$errors, &$errormsg);
 		validate_product_description($HTTP_POST_VARS["description"], &$errors, &$errormsg);
 		validate_product_extended_description($HTTP_POST_VARS["extended_description"], &$errors, &$errormsg);
 		if (empty($errormsg)) {
@@ -91,7 +91,8 @@ switch (nvl($mode)) {
 			$frm["discount"] = $HTTP_POST_VARS["discount"];
 			$frm["discqty"] = $HTTP_POST_VARS["discqty"];
 			$frm["weight"] = $HTTP_POST_VARS["weight"];
-			$frm["on_special"] = $HTTP_POST_VARS["on_special"];
+			$frm["special_flag"] = $HTTP_POST_VARS["special_flag"];
+			$frm["special_level"] = $HTTP_POST_VARS["special_level"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["extended_description"] = $HTTP_POST_VARS["extended_description"];
 			$frm["submit_caption"] = $Add_Product;
@@ -109,7 +110,7 @@ switch (nvl($mode)) {
 		if ($HTTP_POST_VARS["old_product_id"] != $HTTP_POST_VARS["product_id"]) {
 			product_id_exists($HTTP_POST_VARS["product_id"], &$errors, &$errormsg);
 		}
-		validate_on_special($HTTP_POST_VARS["on_special"], &$errors, &$errormsg);
+		validate_special_level($HTTP_POST_VARS["special_level"], &$errors, &$errormsg);
 		validate_product_name($HTTP_POST_VARS["name"], &$errors, &$errormsg);
 		validate_price($HTTP_POST_VARS["price"], &$errors, &$errormsg);
 		validate_discount($HTTP_POST_VARS["discount"], $HTTP_POST_VARS["discqty"], &$errors, &$errormsg);
@@ -156,7 +157,8 @@ switch (nvl($mode)) {
 			$frm["discount"] = $HTTP_POST_VARS["discount"];
 			$frm["discqty"] = $HTTP_POST_VARS["discqty"];
 			$frm["weight"] = $HTTP_POST_VARS["weight"];
-			$frm["on_special"] = $HTTP_POST_VARS["on_special"];
+			$frm["special_flag"] = $HTTP_POST_VARS["special_flag"];
+			$frm["special_level"] = $HTTP_POST_VARS["special_level"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["extended_description"] = $HTTP_POST_VARS["extended_description"];
 			$frm["submit_caption"] = $Save_Changes;
@@ -224,7 +226,8 @@ function print_add_product_form($category_id = 1) {
 	$frm["discount"] = "";
 	$frm["discqty"] = "";
 	$frm["weight"] = "";
-	$frm["on_special"] = "";
+	$frm["special_flag"] = 0;
+	$frm["special_level"] = "";
 	$frm["description"] = "";
 	$frm["extended_description"] = "";
 	$frm["submit_caption"] = $Add_Product;
@@ -335,7 +338,6 @@ function print_details_product($product_id) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	global $special_th;
 	global $weightunity;
 	include ($CFG->global);
 
@@ -385,7 +387,7 @@ function delete_product($product_id) {
 
 	/* load up the information for the product */
 	$qid = db_query("
-	SELECT imagetype
+	SELECT name, imagetype
 	FROM products
 	WHERE id = '$product_id'
 	");
@@ -473,8 +475,44 @@ function insert_product($frm, $HTTP_POST_FILES) {
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
 	$qid = db_query("
-	INSERT INTO products (id, name, brand_id, price, iva_id, discount, discqty, weight, on_special, description, extended_description, imagetype, imagewidth, imageheight, thumbwidth, thumbheight)
-	VALUES ('$frm[product_id]', '$frm[name]', '$frm[brand_id]', '$frm[price]', '$frm[iva_id]', '$frm[discount]', '$frm[discqty]', '$frm[weight]', '$frm[on_special]', '$frm[description]', '$frm[extended_description]', '$type', '$size[0]', '$size[1]', '$thumbsize[0]', '$thumbsize[1]')
+	INSERT INTO products (
+		id
+		,name
+		,brand_id
+		,price
+		,iva_id
+		,discount
+		,discqty
+		,weight
+		,special_flag
+		,special_level
+		,description
+		,extended_description
+		,imagetype
+		,imagewidth
+		,imageheight
+		,thumbwidth
+		,thumbheight
+		)
+	VALUES (
+		'$frm[product_id]'
+		,'$frm[name]'
+		,'$frm[brand_id]'
+		,'$frm[price]'
+		,'$frm[iva_id]'
+		,'$frm[discount]'
+		,'$frm[discqty]'
+		,'$frm[weight]'
+		,'$frm[special_flag]'
+		,'$frm[special_level]'
+		,'$frm[description]'
+		,'$frm[extended_description]'
+		,'$type'
+		,'$size[0]'
+		,'$size[1]'
+		,'$thumbsize[0]'
+		,'$thumbsize[1]'
+		)
 	");
 
 	/* add this product under the specified categories */
@@ -599,7 +637,8 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 		,discount = '$frm[discount]'
 		,discqty = '$frm[discqty]'
 		,weight = '$frm[weight]'
-		,on_special = '$frm[on_special]'
+		,special_flag = '$frm[special_flag]'
+		,special_level = '$frm[special_level]'
 		,description = '$frm[description]'
 		,extended_description = '$frm[extended_description]'
 		,imagetype = '$type'
@@ -776,12 +815,13 @@ function import_products($HTTP_POST_FILES) {
 			$fldarr[7] = ereg_replace("\'","",$fldarr[7]);
 			$fldarr[8] = ereg_replace("\'","",$fldarr[8]);
 			$fldarr[9] = ereg_replace("\'","",$fldarr[9]);
+			$fldarr[10] = ereg_replace("\'","",$fldarr[10]);
 
-//			$fldarr[10] = ereg_replace("\'","",$fldarr[10]);
-			$fldarr[10] = ereg_replace("'","\'",$fldarr[10]);
-			$fldarr[10] = ereg_replace("\"","\\\"",$fldarr[10]);
+//			$fldarr[11] = ereg_replace("\'","",$fldarr[11]);
 			$fldarr[11] = ereg_replace("'","\'",$fldarr[11]);
 			$fldarr[11] = ereg_replace("\"","\\\"",$fldarr[11]);
+			$fldarr[12] = ereg_replace("'","\'",$fldarr[12]);
+			$fldarr[12] = ereg_replace("\"","\\\"",$fldarr[12]);
 
 			/* ... and let's see if the product already exists ... */
 			$qid = db_query("
@@ -792,8 +832,34 @@ function import_products($HTTP_POST_FILES) {
 				if ($frm[extended_description] == "")
 					$frm[extended_description] = $frm[description];
 				$qid = db_query("
-				INSERT INTO products (id, name, brand_id, price, iva_id, discount, discqty, weight, on_special, description, extended_description)
-				VALUES ('$fldarr[1]', '$fldarr[2]', '$fldarr[3]', '$fldarr[4]', '$fldarr[5]', '$fldarr[6]', '$fldarr[7]', '$fldarr[8]', '$fldarr[9]', '$fldarr[10]', '$fldarr[11]')
+				INSERT INTO products (
+					id
+					,name
+					,brand_id
+					,price
+					,iva_id
+					,discount
+					,discqty
+					,weight
+					,special_flag
+					,special_level
+					,description
+					,extended_description
+					)
+				VALUES (
+					'$fldarr[1]'
+					,'$fldarr[2]'
+					,'$fldarr[3]'
+					,'$fldarr[4]'
+					,'$fldarr[5]'
+					,'$fldarr[6]'
+					,'$fldarr[7]'
+					,'$fldarr[8]'
+					,'$fldarr[9]'
+					,'$fldarr[10]'
+					,'$fldarr[11]'
+					,'$fldarr[12]'
+					)
 				");
 				/* ... and create it in the products_categories table ... */
 				$qid = db_query("
@@ -814,9 +880,10 @@ function import_products($HTTP_POST_FILES) {
 					,discount = '$fldarr[6]'
 					,discqty = '$fldarr[7]'
 					,weight = '$fldarr[8]'
-					,on_special = '$fldarr[9]'
-					,description = '$fldarr[10]'
-					,extended_description = '$fldarr[11]'
+					,special_flag = '$fldarr[9]'
+					,special_level = '$fldarr[10]'
+					,description = '$fldarr[11]'
+					,extended_description = '$fldarr[12]'
 				WHERE id = '$fldarr[1]'
 				");
 				/* ... then, let's see if the product already exists with this category ... */
