@@ -17,8 +17,6 @@
 /* turn on verbose error reporting (15) to see all warnings and errors */
 //error_reporting(15);
 
-$special_th = 100;
-
 /* define a generic object */
 class object {};
 
@@ -78,11 +76,14 @@ if (! isset($SESSION)) {
 }
 
 // Loaded modules
-$SESSION["frames_used"] = 1;
-$SESSION["catbrowser_target"] = "bodyframe";
-//$SESSION["frames_used"] = 0;
-//$SESSION["catbrowser_target"] = "main";
-$SESSION["layersmenu_used"] = 1;
+if (! isset($SESSION["frames_used"])) {
+	$SESSION["frames_used"] = 1;
+	$SESSION["catbrowser_target"] = "bodyframe";
+//	$SESSION["frames_used"] = 0;
+//	$SESSION["catbrowser_target"] = "main";
+}
+if (! isset($SESSION["layersmenu_used"]))
+	$SESSION["layersmenu_used"] = 1;
 $SESSION["brand_used"] = 1;
 $SESSION["iva_used"] = 0;
 $SESSION["iva_value"] = 0;	// not significant if IVA is used
@@ -178,6 +179,8 @@ $SESSION["product_name_length"] = 100;
 $SESSION["product_description_length"] = 500;
 $SESSION["product_extended_description_length"] = 2000;
 $SESSION["discqtymax"] = 1000;
+$SESSION["order_state_name_length"] = 100;
+$SESSION["order_state_description_length"] = 255;
 
 $SESSION["products_per_page"] = 10;	// max number of products to be shown per page (search results, admin products page)
 $SESSION["max_results"] = 100;		// max number of search results to accept the search request
@@ -186,6 +189,7 @@ $SESSION["orders_per_page"] = 10;	// max number of orders to be shown per page (
 $SESSION["categories_per_page"] = 10;	// max number of categories to be shown per page (admin orders page)
 $SESSION["brands_per_page"] = 10;	// max number of brands to be shown per page (admin brands page)
 $SESSION["iva_per_page"] = 10;		// max number of iva percentuals to be shown per page (admin iva page)
+$SESSION["orders_states_per_page"] = 10; // max number of orders states to be shown per page (admin orders state page)
 
 $ordersdb[Customer]	= "Customer      :";
 $ordersdb[Phone]	= "Phone Contact :";
