@@ -18,7 +18,7 @@
  * MAIN
  *****************************************************************************/
 include("application.inc.php");
-load_on_specials(&$qid);
+load_special_products(&$qid);
 include($CFG->templatedir.$SESSION["lang"]."/index.ihtml");
 include("$CFG->templatedir"."footer.ihtml");
 
@@ -26,19 +26,18 @@ include("$CFG->templatedir"."footer.ihtml");
  * FUNCTIONS
  *****************************************************************************/
 
-function load_on_specials(&$qid) {
-/* loads a list of products that are on special */
+function load_special_products(&$qid) {
+/* loads the list of special products */
 	global $CFG;
 	global $SESSION;
-	global $special_th;
 	global $weightunity;
 	include ($CFG->global);
 
 	$qid = db_query("
 			SELECT p.* , b.name AS bname
 			FROM products p JOIN brands b ON (p.brand_id = b.id)
-			WHERE on_special > $special_th
-			ORDER BY on_special ASC
+			WHERE special_flag = 1
+			ORDER BY special_level ASC
 			");
 }
 
