@@ -81,7 +81,7 @@ function build_category_tree(&$output, &$preselected, $parent=1, $indent="") {
  * is easy to understand.
  */
 
-	$qid = db_query("SELECT id, name FROM categories WHERE parent_id = '$parent' ORDER BY on_special, name");
+	$qid = db_query("SELECT id, name FROM categories WHERE parent_id = '$parent' ORDER BY special_level, name");
 
 	$numr = db_num_rows($qid);
 	for ($i=0;$i<$numr;$i++) {
@@ -102,7 +102,7 @@ function build_catbrowser(&$output, $parent=1, $indent="..") {
  */
 	global $CFG, $SESSION;
 
-        $qid = db_query("SELECT id, name FROM categories WHERE parent_id = '$parent' AND id <> 1 ORDER BY on_special, name");
+        $qid = db_query("SELECT id, name FROM categories WHERE parent_id = '$parent' AND id <> 1 ORDER BY special_level, name");
 
         $numr = db_num_rows($qid);
         for ($i=0;$i<$numr;$i++) {
@@ -122,7 +122,7 @@ function build_catbrowser_js(&$output, $parent=1, $indent="..") {
  */
 	global $CFG;
 
-        $qid = db_query("SELECT id, name FROM categories WHERE parent_id = '$parent' AND id <> 1 ORDER BY on_special, name");
+        $qid = db_query("SELECT id, name FROM categories WHERE parent_id = '$parent' AND id <> 1 ORDER BY special_level, name");
 
         $numr = db_num_rows($qid);
         for ($i=0;$i<$numr;$i++) {
@@ -227,7 +227,7 @@ function get_category_tree($id=1) {
 
 	global $CFG;
 
-	$qid = db_query("SELECT parent_id, name FROM categories WHERE id = '$id' ORDER BY on_special, name");
+	$qid = db_query("SELECT parent_id, name FROM categories WHERE id = '$id' ORDER BY special_level, name");
 	if (db_num_rows($qid)) {
 		list($parent, $name) = db_fetch_row($qid, 0);
 		$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>$name</a>";
@@ -1024,6 +1024,33 @@ function validate_discount($discount, $discqty, &$errors, &$msg) {
 	}
 }
 
+function validate_order_state_name($order_state_name, &$errors, &$msg) {
+
+	global $CFG, $SESSION;
+	include ($CFG->global);
+
+	$stripped_order_state_name = str_replace(" ", "", $order_state_name);
+
+	if (empty($order_state_name) || empty($stripped_order_state_name)) {
+		$errors->order_state_name = true;
+		$msg .= "<li>".$empty_order_state_name;
+	} else if (strlen($order_state_name) > $SESSION["order_state_name_length"]) {
+		$errors->order_state_name = true;
+		$msg .= "<li>".$order_state_name_too_long;
+	}
+}
+
+function validate_order_state_description($order_state_description, &$errors, &$msg) {
+
+	global $CFG, $SESSION;
+	include ($CFG->global);
+
+	if (strlen($order_state_description) > $SESSION["order_state_description_length"]) {
+		$errors->order_state_description = true;
+		$msg .= "<li>".$order_state_description_too_long;
+	}
+}
+
 function validate_searched_discount($discount, &$errors, &$msg) {
 
 	eregi ("[0-9]{0,}[.]{0,1}[0-9]{0,}", $discount, $matched_discount);
@@ -1074,20 +1101,20 @@ function validate_weight($weight, &$errors, &$msg) {
 	}
 }
 
-function validate_on_special($on_special, &$errors, &$msg) {
+function validate_special_level($special_level, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
 	include ($CFG->global);
 
 /*
-	if ($on_special == "") {
-		$errors->on_special = true;
-		$msg .= "<li>".$on_special_empty;
-	} else if ((string) ((int) $on_special) != "$on_special") {
+	if ($special_level == "") {
+		$errors->special_level = true;
+		$msg .= "<li>".$special_level_empty;
+	} else if ((string) ((int) $special_level) != "$special_level") {
 */
-	if ((string) ((int) $on_special) != "$on_special" && $on_special != "") {
-		$errors->on_special = true;
-		$msg .= "<li>".$on_special_notint;
+	if ((string) ((int) $special_level) != "$special_level" && $special_level != "") {
+		$errors->special_level = true;
+		$msg .= "<li>".$special_level_notint;
 	}
 }
 
