@@ -94,6 +94,10 @@ $Contact_us = "Contattaci !";
 $Signup_Italy = "Iscrizione (Italia)";
 $Signup_non_Italy = "Iscrizione (Estero)";
 $Enterprises_Signup = "Iscrizione Aziende";
+$Turn_Off_Frames = "Disabilita frame";
+$Turn_On_Frames = "Abilita frame";
+$Turn_On_Layers_Menu = "Abilita men&ugrave; a layers";
+$Turn_Off_Layers_Menu = "Disabilita men&ugrave; a layers";
 $Shopping = "Acquisto";
 $Purchase_Now = "Acquista ora";
 $Search_the_Catalog = "Cerca nel catalogo";
@@ -116,22 +120,24 @@ $Special_Products = "Prodotti speciali";
 
 $Add_User = "Aggiungi utente";
 $Categories_Management = "Amministrazione delle categorie";
-$C_Import_Categories = "Importa categorie";
+$Import_Categories = "Importa categorie";
 $Brands_Management = "Amministrazione delle marche";
-$C_Import_Brands = "Importa marche";
-$C_Import_IVA = "Importa percentuali IVA";
+$Import_Brands = "Importa marche";
+$Import_IVA = "Importa percentuali IVA";
 $IVA_Management = "Amministrazione dei valori di IVA";
 $Orders_Log_ca = "Diario degli ordini - Contrassegno";
 $Orders_Log_cc = "Diario degli ordini - Carta di Credito";
 $Products_Management = "Amministrazione dei prodotti";
-$C_Import_Products = "Importa prodotti";
+$Import_Products = "Importa prodotti";
 $Save_Changes = "Salva modifiche";
 $Users_Admin = "Amministrazione degli utenti";
 $U_Import_Users = "Importa utenti";
 $_Import_File = "File da Importare:";
 $Import_Images_Button_Label = "Importa Immagini";
-$C_Import_Images = "Importa immagini";
+$Import_Images = "Importa immagini";
 $End_Import = "Import Terminato.";
+$Orders_States_Management = "Gestione stati degli ordini";
+$Add_Order_State = "Aggiungi stato";
 
 ////////////////////////////////////////////////////////////
 // admin templates
@@ -144,9 +150,9 @@ $Extended_Description = "Descrizione estesa";
 $Discount = "Sconto";
 $Starting_from = "a partire da";
 $C_Add_Category = "[+C] Aggiungi categoria";
-$C_Add_Brand = "[+C] Aggiungi marca";
-$C_Add_IVA = "[+C] Aggiungi percentuale IVA";
-$C_Add_Product = "[+P] Aggiungi prodotto";
+$B_Add_Brand = "[+M] Aggiungi marca";
+$I_Add_IVA = "[+I] Aggiungi percentuale IVA";
+$P_Add_Product = "[+P] Aggiungi prodotto";
 $Action = "Azione";
 $User = "Utente";
 $The_user = "L'utente";
@@ -159,6 +165,7 @@ $has_been_deleted_female_singular = "&egrave; stata eliminata";
 $has_been_deleted_male_singular = "&egrave; stato eliminato";
 $All_the_products_and_sub_categories_belonging_to = "Tutti i prodotti e le sottocategorie appartenenti a";
 $have_been_reassigned_to_male_plural = "sono stati riassegnati a";
+$actually_its_name_is_male_singular = "attualmente si chiama";
 $actually_its_name_is_female_singular = "attualmente si chiama";
 $actually_its_value_is_female_singular = "attualmente vale";
 $Add_a_subcategory_under = "Aggiungi una sottocategoria di";
@@ -175,8 +182,6 @@ $Delete_this_order = "Cancella questo ordine";
 $Order = "Ordine";
 $Orders = "Ordini";
 $The_order = "L'ordine";
-$Sent = "Spedito";
-$Paid = "Pagato";
 $Ordered = "Ordinato";
 $Ordered_By = "Ordinato da";
 $Amount = "Ammontare";
@@ -185,12 +190,14 @@ $Enterprise_Id_N = "Partita IVA";
 $ID = "ID";
 $Current_Price = "Prezzo attuale";
 $Purchase_Price = "Prezzo d'acquisto";
-$Order_Status = "Stato dell'ordine";
-$ID_and_Status = "ID - Stato";
-$Status = "Stato";
+$Order_State = "Stato dell'ordine";
+$Orders_States = "Stati degli ordini";
+$ID_and_State = "ID - Stato";
+$StateO = "Stato";
 $Cust_Info = "Info cliente";
 $Details = "Dettagli";
-$Special = "Speciale";
+$Special_Flag = "Prodotto Speciale";
+$Special_Level = "Livello";
 $Normal = "Normale";
 $Edit_this_product = "Modifica questo prodotto";
 $View_product_details = "Mostra dettagli del prodotto";
@@ -212,6 +219,11 @@ $Reset_password_for = "Reinizializza la password di";
 $Change_password_for = "Modifica la password di";
 $Edit_this_user = "Modifica questo utente";
 $Email_this_user = "Scrivi a questo utente";
+$S_Add_Order_State = "[+S] Aggiungi stato";
+$Import_Orders_States = "Importa stati";
+$The_Order_State = "Lo stato";
+$The_order_state = "Lo stato";
+$Order_State_reset_for_orders = "Lo stato degli ordini &egrave; stato azzerato per tutti gli ordini in tale stato";
 
 ////////////////////////////////////////////////////////////
 // shopping scripts
@@ -461,8 +473,8 @@ $not_valid_weight = "Peso non valido";
 $weight_is_zero = "Il Peso deve essere maggiore di zero";
 $weight_over_max = "Peso eccessivo: " . $SESSION["weightmax"] . " " . $weightunity . " max";
 
-$on_special_empty = "Riempire il campo \"" . $Special . "\"";
-$on_special_notint = "Il campo \"" . $Special . "\" deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
+$special_level_empty = "Riempire il campo \"" . $Special_Level . "\"";
+$special_level_notint = "Il campo \"" . $Special_Level . "\" deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
 
 $product_description_too_long = "La descrizione del prodotto &egrave; troppo lunga: ".$SESSION["product_description_length"]." caratteri max";
 $product_extended_description_too_long = "La descrizione estesa del prodotto &egrave; troppo lunga: ".$SESSION["product_extended_description_length"]." caratteri max";
@@ -472,6 +484,14 @@ $no_product_image_chosen = "Non &egrave; stata scelta una nuova immagine per rap
 $image_upload_failed = "Upload dell'immagine fallito";
 $unsupported_image_type = "Tipo di immagine non supportato";
 
+////////////////////////////////////////////////////////////
+// add and update order state
+////////////////////////////////////////////////////////////
+
+$empty_order_state_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
+$order_state_name_too_long = "Il nome dello stato dell'ordine &egrave; troppo lungo: ".$SESSION["order_state_name_length"]." caratteri max";
+$order_state_description_too_long = "La descrizione dello stato dell'ordine &egrave; troppo lunga: ".$SESSION["order_state_description_length"]." caratteri max";
+
 ////////////////////////////////////////////////////////////
 // advanced search
 // prefix table: L = left	R = right
