@@ -94,6 +94,10 @@ $Contact_us = "Contact us !";
 $Signup_Italy = "Signup (Italy)";
 $Signup_non_Italy = "Signup (outside of Italy)";
 $Enterprises_Signup = "Enterprises Signup";
+$Turn_Off_Frames = "Turn off frames";
+$Turn_On_Frames = "Turn on frames";
+$Turn_On_Layers_Menu = "Turn on layers menu";
+$Turn_Off_Layers_Menu = "Turn off layers menu";
 $Shopping = "Shopping";
 $Purchase_Now = "Purchase Now";
 $Search_the_Catalog = "Search the Catalog";
@@ -116,22 +120,24 @@ $Special_Products = "Special Products";
 
 $Add_User = "Add User";
 $Categories_Management = "Category Management";
-$C_Import_Categories = "Import categories";
+$Import_Categories = "Import categories";
 $Brands_Management = "Brands Management";
-$C_Import_Brands = "Import Brands";
-$C_Import_IVA = "Import IVA percentuals";
+$Import_Brands = "Import Brands";
+$Import_IVA = "Import IVA percentuals";
 $IVA_Management = "IVA Management";
 $Orders_Log_ca = "Orders Log - Cash On Delivery";
 $Orders_Log_cc = "Orders Log - Credit Card";
 $Products_Management = "Products Management";
-$C_Import_Products = "Import products";
+$Import_Products = "Import products";
 $Save_Changes = "Save Changes";
 $Users_Admin = "Users Management";
 $U_Import_Users = "Import users";
 $_Import_File = "File to be Imported:";
 $Import_Images_Button_Label = "Importa Immagini";
-$C_Import_Images = "Import Images";
+$Import_Images = "Import Images";
 $End_Import = "Import Completed.";
+$Orders_States_Management = "Orders States Management";
+$Add_Order_State = "Add Order State";
 
 ////////////////////////////////////////////////////////////
 // admin templates
@@ -144,9 +150,9 @@ $Extended_Description = "Extended Description";
 $Discount = "Discount";
 $Starting_from = "starting from";
 $C_Add_Category = "[+C] Add Category";
-$C_Add_Brand = "[+C] Add Brand";
-$C_Add_IVA = "[+C] Add IVA percentual";
-$C_Add_Product = "[+P] Add Product";
+$B_Add_Brand = "[+B] Add Brand";
+$I_Add_IVA = "[+I] Add IVA percentual";
+$P_Add_Product = "[+P] Add Product";
 $Action = "Action";
 $User = "User";
 $The_user = "The user";
@@ -159,6 +165,7 @@ $has_been_deleted_female_singular = "has been deleted";
 $has_been_deleted_male_singular = "has been deleted";
 $All_the_products_and_sub_categories_belonging_to = "All the products and sub-categories belonging to";
 $have_been_reassigned_to_male_plural = "have been reassigned to";
+$actually_its_name_is_male_singular = "actually its name is";
 $actually_its_name_is_female_singular = "actually its name is";
 $actually_its_value_is_female_singular = "actually its value is";
 $Add_a_subcategory_under = "Add a subcategory under";
@@ -175,8 +182,6 @@ $Delete_this_order = "Delete this order";
 $Order = "Order";
 $Orders = "Orders";
 $The_order = "The order";
-$Sent = "Sent";
-$Paid = "Paid";
 $Ordered = "Ordered";
 $Ordered_By = "Ordered By";
 $Amount = "Amount";
@@ -185,12 +190,14 @@ $Enterprise_Id_N = "Enterprise Id. N.";
 $ID = "ID";
 $Current_Price = "Current Price";
 $Purchase_Price = "Purchase Price";
-$Order_Status = "Order Status";
-$ID_and_Status = "ID - Status";
-$Status = "Status";
+$Order_State = "Order State";
+$Orders_States = "Orders States";
+$ID_and_State = "ID - State";
+$StateO = "State";
 $Cust_Info = "Cust. Info";
 $Details = "Details";
-$Special = "On Special";
+$Special_Flag = "Special Product";
+$Special_Level = "Special Level";
 $Normal = "Normal";
 $Edit_this_product = "Edit this product";
 $View_product_details = "View product details";
@@ -212,6 +219,11 @@ $Reset_password_for = "Reset password for";
 $Change_password_for = "Change password for";
 $Edit_this_user = "Edit this user";
 $Email_this_user = "Email this user";
+$S_Add_Order_State = "[+S] Add Order State";
+$Import_Orders_States = "Import Orders States";
+$The_Order_State = "The Order State";
+$The_order_state = "The order state";
+$Order_State_reset_for_orders = "The order State has been reset for all orders in the named state";
 
 ////////////////////////////////////////////////////////////
 // shopping scripts
@@ -458,8 +470,8 @@ $not_valid_weight = "Weight not valid";
 $weight_is_zero = "The Weight must be greater than zero";
 $weight_over_max = "Weight too large: " . $SESSION["weightmax"] . " " . $weightunity . " max";
 
-$on_special_empty = "The \"" . $Special . "\" entry is empty; please fill it";
-$on_special_notint = "The \"" . $Special . "\" entry must contain an integer number: only ciphers, not any other character";
+$special_level_empty = "The \"" . $Special_Level . "\" entry is empty; please fill it";
+$special_level_notint = "The \"" . $Special_Level . "\" entry must contain an integer number: only ciphers, not any other character";
 
 $product_description_too_long = "Product Description too much long: ".$SESSION["product_description_length"]." characters max";
 $product_extended_description_too_long = "Product Extended Description too much long: ".$SESSION["product_extended_description_length"]." characters max";
@@ -469,6 +481,14 @@ $no_product_image_chosen = "No new image has been chosen to represent the produc
 $image_upload_failed = "Image upload failed";
 $unsupported_image_type = "Unsupported image type";
 
+////////////////////////////////////////////////////////////
+// add and update order state
+////////////////////////////////////////////////////////////
+
+$empty_order_state_name = "The Order State Name is empty; please fill it";
+$order_state_name_too_long = "Order State Name too much long: ".$SESSION["order_state_name_length"]." characters max";
+$order_state_description_too_long = "Order State Description too much long: ".$SESSION["order_state_description_length"]." characters max";
+
 ////////////////////////////////////////////////////////////
 // advanced search
 // prefix table: L = left	R = right
