@@ -41,7 +41,7 @@ $DOC_TITLE = $Signup;
 include("$CFG->templatedir"."header.ihtml");
 include("$CFG->templatedir"."form_header.ihtml");
 if (empty($errormsg)) {	// we are loading the form for the first time
-	$frm["acceptadvert"] = $yes;
+	$frm["acceptadvert"] = 1;
 }
 include("templates/signup_form-".$usertype.".ihtml");
 include("$CFG->templatedir"."footer.ihtml");
@@ -110,10 +110,26 @@ function insert_user(&$frm, $usertype) {
 
 	$qid = db_query("
 	INSERT INTO users (
-		username, password, usertype, firstname, lastname,
-		fiscalcode, address, number, city, state, zip_code,
-		phone, fax, mobilephone, email,
-		authdata, acceptadvert, notes, date, fromip
+		username
+		,password
+		,usertype
+		,firstname
+		,lastname
+		,fiscalcode
+		,address
+		,number
+		,city
+		,state
+		,zip_code
+		,phone
+		,fax
+		,mobilephone
+		,email
+		,authdata
+		,acceptadvert
+		,notes
+		,date
+		,fromip
 	) VALUES (
 		 '$frm[username]'
 		,'$frm[password]'
